@@ -6,6 +6,7 @@ import requests
 from .errors import AuthenticationError
 from . import settings
 from . import util
+from . import profile
 
 
 log = logging.getLogger(__name__)
@@ -45,6 +46,7 @@ class Session(requests.Session):
                                                                        log_in_name))
         log.debug(login_response.content.decode('utf8'))
         session.log_in_name = log_in_name
+        session.headers.update(cls.default_login_headers)
         return session
 
     def __init__(self, *args, **kwargs):
@@ -72,4 +74,10 @@ class Session(requests.Session):
         return self.get('{0}{1}'.format(util.BASE_URI, path), *args, **kwargs)
 
     def okc_post(self, path, *args, **kwargs):
-        return self.post('{0}{1}'.format(util.BASE_URI, path), *args, **kwargs)
\ No newline at end of file
+        return self.post('{0}{1}'.format(util.BASE_URI, path), *args, **kwargs)
+
+    def get_profile(self, username):
+        return profile.Profile(self, username)
+
+    def get_current_user_profile(self):
+        return self.get_profile(self.log_in_name)
